@@ -32,6 +32,11 @@ G_BEGIN_DECLS
 #else
 #define GAPC_VERSION VERSION
 #endif
+
+#ifndef ICON_DIR
+#define ICON_DIR "/usr"
+#endif
+
 #define GAPC_PROG_NAME    "gapcmon"
 #define GAPC_GROUP_TITLE "<i>  Uninterruptible Power Supply Monitor...</i>\n  for APCUPSD"
 #define GAPC_WINDOW_TITLE  "gapcmon: UPS Information Panels"
@@ -78,6 +83,7 @@ G_BEGIN_DECLS
 #define SKNET_REG_ARRAY  1024
 #define SKNET_STR_ARRAY   256
 
+
 typedef struct _SKNET_Control_Data {
   gint        cb_id;           
   GIOChannel *ioc;                                 /* socket io channel */
@@ -108,7 +114,7 @@ typedef enum _Control_Block_id {
     CB_N_ID
 } GAPCDataID;
 
-   typedef enum _State_Icons_IDs {
+typedef enum _State_Icons_IDs {
    GAPC_ICON_ONLINE,
    GAPC_ICON_ONBATT,
    GAPC_ICON_CHARGING,
